/* 
 * File:   SED1565.h
 * Author: chengo_cc
 *
 * Created on 17 December 2015, 11:07 AM
 */

#ifndef SED1565_H
//------------------------------------------------------------------------------
#include "GLCD_prototypes.h"
//------------------------------------------------------------------------------
#define CLEAR       0x00
#define FILL        0xFF
#define pgLen       8
#define pgWidth     128
//------------------------------------------------------------------------------
void LCD_init()
{
  //All pins as outputs
  CS1_dir = 0;
  A0_dir  = 0;
  SCL_dir = 0;
  SDO_dir = 0;
  //See Datasheet for elaboration
  LCD_startline(0);        //Start at line 0.
  LCD_command(0xA6);       //Display: Normal.
  LCD_command(0xA1);       //ADC (Address Counter) Selection: Normal.
  LCD_command(0xAF);       //LCD On.
}
//------------------------------------------------------------------------------
void LCD_command(unsigned char command)
{
  A0  = 0;                 //Command.

  CS1 = 0;
  LCD_write(command);
  CS1 = 1;
}
//------------------------------------------------------------------------------
void LCD_data(unsigned char data)
{
  A0 = 1;                  //Data.

  CS1 = 0;
  LCD_write(data);
  CS1 = 1;
}
//------------------------------------------------------------------------------
void LCD_write(unsigned char data)
{
  //Transfer <Tx> byte MSB first.
  for(int Tx = 0; Tx < 8; Tx++)
  {
   SCL = 0;
   SDO = ( ((data << Tx) & 0x80) ? 1 : 0 );
   SCL = 1;                              // Toggle the Serial Clock pin
  }
}
//------------------------------------------------------------------------------
void LCD_fill(unsigned char fill)
{
  for(int pg = 0; pg < pgLen; pg++)
  {
    LCD_page(pg);        //Set in software
    LCD_column(0);       //Set to zero then increments automatically in Hardware
    for(int col = 0; col < pgWidth; col++)
    {
      LCD_data( fill );
    }
  }
}
//------------------------------------------------------------------------------
void LCD_page(unsigned int pg)
{
  pg = page[pg];
  LCD_command(pg);
}
//------------------------------------------------------------------------------
void LCD_column(unsigned int column)
{
  //Split column to into Nibbles
  char lowerNibble =   column & 0x0F;         //Eliminate upper nibble. Retain lower nibble.
  char higherNibble =( column & 0xF0 ) >> 4;  //Eliminate lower nibble. Retain upper nibble and shift right.

  LCD_command( 0x10 | higherNibble );      //Check SED1565 Datasheet for explanation
  LCD_command( lowerNibble );
}
//-------------------------64 Lines: 0 - 63-------------------------------------
void LCD_startline(unsigned int line)
{
  LCD_command( 0x40 | line );              //See Datasheet
}
//------------------------------------------------------------------------------
void LCD_string(int page, int column, unsigned char *text)
{
  LCD_page(page);
  LCD_column(column);

  while( *text != '\0' )
  {
    char row = *text++;
    for(int col = 0; col < 8; col++)
    {
      LCD_data( bitmapText[row-32][col] ); //(row-32): because the first 32 ASCII codes are unimplemnted
    }
  }
}
//------------------------------------------------------------------------------
void LCD_image(unsigned char *image)
{
  unsigned char* img;                //Stores address of array elements of the image bitmap.

  for(int pg = 0; pg < pgLen; pg++)
  {
    LCD_page(pg);              //Pages: 0-7.
    LCD_column(0);             //Set once for each page then self increments in hardware.
    img = &image[pg*pgWidth];  //row*pgWidth: Offset value for start address to each "row" in image array. Alleviates need for 2-dimensional array.
    for(int col = 0; col < pgWidth; col++) //Columns: 0 - 131...since 132 x 64
    {
      LCD_data( img[col] );    //Dereference the address (via "[]") to get actual value at that postion.
    }
  }
}
//----------------------------------------------------------------------------*/
#define	SED1565_H

#ifdef	__cplusplus
extern "C" {
#endif




#ifdef	__cplusplus
}
#endif

#endif	/* SED1565_H */

